#ifdef GL_ES
	precision mediump float;
#endif

uniform sampler2D u_sampler;
uniform sampler2D u_sampler_bump;
uniform sampler2D u_sampler_params;

uniform mat4 u_modelview;
uniform mat4 u_modelview_scene;
uniform mat3 u_normal_matrix;


varying mat3 v_inv_tbn;

varying vec3 v_pos;
varying vec2 v_uv;

varying vec4 v_light_pos;




void main(void)
{

    vec4 c = texture2D(u_sampler, v_uv);
    vec4 c2 = texture2D(u_sampler_bump, v_uv);
    vec4 c3 = texture2D(u_sampler_params, v_uv);
    
    vec3 norm_ts = vec3(1.0, 1.0, -1.0) + vec3(-2.0, -2.0, 2.0)*vec3(c2); // for x(R)>  y(G)^  z(B).

	
	vec3 vector_to_camera = normalize(-v_pos);
	vec3 vector_to_light = normalize(v_light_pos.xyz - v_pos*v_light_pos.w);
	vec3 norm = normalize( v_inv_tbn * norm_ts ); // modelview-space
	

	vec3 diffuse_color = vec3(0.95, 0.75, 0.65);
	vec3 ambient_color = vec3(0.0, 0.25, 0.5);
	vec3 specular_color = vec3(0.0, 1.0, 0.3);
	float ambient_k = 0.2;
	float attenuation_k = 0.00;
	float shininess_k = 100.0;

    
    
    // 1. Ambient
    vec3 ambient = ambient_k * vec3(c) * ambient_color;
    
    // 2. Diffuse
    float diffuse_k = clamp( dot(vector_to_light, norm ), -0.001, 1.0 ); 
    vec3 diffuse = diffuse_k * vec3(c) * diffuse_color;
    
    // 3. Specular
    
	float s = max(0.0, dot(vector_to_camera, reflect(-vector_to_light, norm)) );
    float diffuse_k_sign_koef = 0.5 + 0.5*sign(diffuse_k);
    float specular_k = c3.r * diffuse_k_sign_koef * pow(s, shininess_k);
	vec3 specular = specular_k * specular_color; 
	
	
	// 4. Attenuation
	float distance_to_light = length(v_light_pos.xyz - v_pos*v_light_pos.w);
	float attenuation = 1.0 / ( 1.0 + attenuation_k * distance_to_light * distance_to_light );
	
	// 5. Emission
	float emission_k = c3.b; // * vec3(c);
    
    // Sum:
    vec3 sum = emission_k*vec3(c) + (1.0-emission_k)*(ambient + attenuation*(diffuse + specular));
    //vec3 sum = ambient + attenuation*(diffuse);
    
	//gl_FragColor = c + 0.1*vec4(sum, 1.0) + vec4(normalize(vec3(v_test)), 1.0);
	gl_FragColor = vec4(sum, 1.0);

	
	// Gamma (?)
	// vec3 gamma = vec3(1.0/2.2);
	// gl_FragColor.rgb = pow(gl_FragColor.rgb, gamma);
	
	
	
}  
