#ifdef GL_ES
	precision mediump float;
#endif

varying vec2 v_uv;
varying vec3 v_pos; 
uniform sampler2D u_sampler;
uniform sampler2D u_sampler_blur;

uniform mat4 u_color_matrix;

uniform float u_aspect;
uniform float u_blur_scale;

uniform float u_time;

#define M_PI 3.141592654

void main() {

    vec4 c = texture2D(u_sampler, v_uv);
    vec4 c_blur = texture2D(u_sampler_blur, v_uv);
    
    c = u_color_matrix * c + 0.001*c_blur;
    
    float blur_base = u_blur_scale; // 0.012;
    
    vec2 blur_offset = vec2( blur_base * c_blur.r, blur_base * c_blur.r * u_aspect );
		
	// Grouping texcoord variables in order to make it work in the GMA 950. See post #13
	// in this thread:
	// http://www.idevgames.com/forums/thread-3467.html
	vec2 tc0 = v_uv + vec2(-blur_offset.s, -blur_offset.t);
	vec2 tc1 = v_uv + vec2(         0.0, -blur_offset.t);
	vec2 tc2 = v_uv + vec2(+blur_offset.s, -blur_offset.t);
	vec2 tc3 = v_uv + vec2(-blur_offset.s,          0.0);
	vec2 tc4 = v_uv + vec2(         0.0,          0.0);
	vec2 tc5 = v_uv + vec2(+blur_offset.s,          0.0);
	vec2 tc6 = v_uv + vec2(-blur_offset.s, +blur_offset.t);
	vec2 tc7 = v_uv + vec2(         0.0, +blur_offset.t);
	vec2 tc8 = v_uv + vec2(+blur_offset.s, +blur_offset.t);
	 
	vec4 col0 = texture2D(u_sampler, tc0);
	vec4 col1 = texture2D(u_sampler, tc1);
	vec4 col2 = texture2D(u_sampler, tc2);
	vec4 col3 = texture2D(u_sampler, tc3);
	vec4 col4 = texture2D(u_sampler, tc4);
	vec4 col5 = texture2D(u_sampler, tc5);
	vec4 col6 = texture2D(u_sampler, tc6);
	vec4 col7 = texture2D(u_sampler, tc7);
	vec4 col8 = texture2D(u_sampler, tc8);
	 
	vec4 sum = (1.0 * col0 + 2.0 * col1 + 1.0 * col2 + 
		        2.0 * col3 + 4.0 * col4 + 2.0 * col5 +
		        1.0 * col6 + 2.0 * col7 + 1.0 * col8) / 16.0; 
    
    /*if (v_uv.s > 0.5) {
	    gl_FragColor = sum; // + clamp(50.0*c_blur, 0.0, 0.1);
    }
    else {
    	gl_FragColor = c;
    };*/
    gl_FragColor = vec4(vec3(sum), 1.0);
    

}

